pub fn point_on_quadratic_bezier<T: Interpolatable>(
points: &[T; 3],
t: f64,
) -> TExpand description
Returns the point on a quadratic bezier curve at the given parameter.
pub fn point_on_quadratic_bezier<T: Interpolatable>(
points: &[T; 3],
t: f64,
) -> TReturns the point on a quadratic bezier curve at the given parameter.