pub struct PathBuilder {
start_point: Option<DVec3>,
points: Vec<DVec3>,
}Expand description
A path builder based on quadratic beziers
Fields
start_point: Option<DVec3>points: Vec<DVec3>Implementations
Sourceimpl PathBuilder
impl PathBuilder
Sourcepub fn move_to(&mut self, point: DVec3) -> &mut Self
pub fn move_to(&mut self, point: DVec3) -> &mut Self
Starts a new subpath and push the point as the start_point
fn assert_started(&self)
Sourcepub fn close_path(&mut self) -> &mut Self
pub fn close_path(&mut self) -> &mut Self
Close the path.
The path is considered closed if the start point is equal to the last point.
If the path is not closed, a line is appended to the end to close it.